@@ -1,5 +1,5 @@
-use std::convert::TryFrom;
-use std::marker::PhantomData;
+use core::convert::TryFrom;
+use core::marker::PhantomData;
 
 use crate::endianness::{EndianKind, Endianness};
 
@@ -76,9 +76,9 @@ macro_rules! int_field {
                 ```
                 "},
                 fn read(storage: &[u8]) -> $type {
-                    let mut value = [0; std::mem::size_of::<$type>()];
+                    let mut value = [0; core::mem::size_of::<$type>()];
                     value.copy_from_slice(
-                        &storage.as_ref()[Self::OFFSET..(Self::OFFSET + std::mem::size_of::<$type>())],
+                        &storage.as_ref()[Self::OFFSET..(Self::OFFSET + core::mem::size_of::<$type>())],
                     );
                     match E::KIND {
                         EndianKind::Big => $type::from_be_bytes(value),
@@ -112,7 +112,7 @@ macro_rules! int_field {
                         EndianKind::Big => value.to_be_bytes(),
                         EndianKind::Little => value.to_le_bytes(),
                     };
-                    storage.as_mut()[Self::OFFSET..(Self::OFFSET + std::mem::size_of::<$type>())]
+                    storage.as_mut()[Self::OFFSET..(Self::OFFSET + core::mem::size_of::<$type>())]
                         .copy_from_slice(&value_as_bytes);
                 }
             }
@@ -120,7 +120,7 @@ macro_rules! int_field {
 
         impl<E: Endianness, const OFFSET_: usize> SizedField for PrimitiveField<$type, E, OFFSET_> {
             /// See [SizedField::SIZE]
-            const SIZE: usize = std::mem::size_of::<$type>();
+            const SIZE: usize = core::mem::size_of::<$type>();
         }
     };
 }
@@ -129,10 +129,12 @@ int_field!(i8);
 int_field!(i16);
 int_field!(i32);
 int_field!(i64);
+int_field!(i128);
 int_field!(u8);
 int_field!(u16);
 int_field!(u32);
 int_field!(u64);
+int_field!(u128);
 
 /// Field type `[u8]`:
 /// This field represents an [open ended byte array](crate#open-ended-byte-arrays-u8).
@@ -244,7 +246,7 @@ impl<E: Endianness, const N: usize, const OFFSET_: usize> SizedField
 mod tests {
     use super::*;
     use crate::endianness::{BigEndian, LittleEndian};
-    use std::convert::TryInto;
+    use core::convert::TryInto;
 
     #[test]
     fn test_i8_littleendian() {
@@ -448,6 +450,58 @@ mod tests {
         assert_eq!(8, PrimitiveField::<i64, BigEndian, 5>::SIZE);
     }
 
+    #[test]
+    fn test_i128_littleendian() {
+        let mut storage = vec![0; 1024];
+
+        type Field1 = PrimitiveField<i128, LittleEndian, 5>;
+        type Field2 = PrimitiveField<i128, LittleEndian, 200>;
+
+        Field1::write(&mut storage, 10i128.pow(30));
+        Field2::write(&mut storage, -(10i128.pow(28)));
+
+        assert_eq!(
+            10i128.pow(30),
+            i128::from_le_bytes((&storage[5..21]).try_into().unwrap())
+        );
+        assert_eq!(
+            -(10i128.pow(28)),
+            i128::from_le_bytes((&storage[200..216]).try_into().unwrap())
+        );
+
+        assert_eq!(10i128.pow(30), Field1::read(&storage));
+        assert_eq!(-(10i128.pow(28)), Field2::read(&storage));
+
+        assert_eq!(16, PrimitiveField::<i128, LittleEndian, 5>::SIZE);
+        assert_eq!(16, PrimitiveField::<i128, LittleEndian, 5>::SIZE);
+    }
+
+    #[test]
+    fn test_i128_bigendian() {
+        let mut storage = vec![0; 1024];
+
+        type Field1 = PrimitiveField<i128, BigEndian, 5>;
+        type Field2 = PrimitiveField<i128, BigEndian, 200>;
+
+        Field1::write(&mut storage, 10i128.pow(30));
+        Field2::write(&mut storage, -(10i128.pow(28)));
+
+        assert_eq!(
+            10i128.pow(30),
+            i128::from_be_bytes((&storage[5..21]).try_into().unwrap())
+        );
+        assert_eq!(
+            -(10i128.pow(28)),
+            i128::from_be_bytes((&storage[200..216]).try_into().unwrap())
+        );
+
+        assert_eq!(10i128.pow(30), Field1::read(&storage));
+        assert_eq!(-(10i128.pow(28)), Field2::read(&storage));
+
+        assert_eq!(16, PrimitiveField::<i128, BigEndian, 5>::SIZE);
+        assert_eq!(16, PrimitiveField::<i128, BigEndian, 5>::SIZE);
+    }
+
     #[test]
     fn test_u8_littleendian() {
         let mut storage = vec![0; 1024];
@@ -650,6 +704,58 @@ mod tests {
         assert_eq!(8, PrimitiveField::<u64, BigEndian, 5>::SIZE);
     }
 
+    #[test]
+    fn test_u128_littleendian() {
+        let mut storage = vec![0; 1024];
+
+        type Field1 = PrimitiveField<u128, LittleEndian, 5>;
+        type Field2 = PrimitiveField<u128, LittleEndian, 200>;
+
+        Field1::write(&mut storage, 10u128.pow(30));
+        Field2::write(&mut storage, 10u128.pow(28));
+
+        assert_eq!(
+            10u128.pow(30),
+            u128::from_le_bytes((&storage[5..21]).try_into().unwrap())
+        );
+        assert_eq!(
+            10u128.pow(28),
+            u128::from_le_bytes((&storage[200..216]).try_into().unwrap())
+        );
+
+        assert_eq!(10u128.pow(30), Field1::read(&storage));
+        assert_eq!(10u128.pow(28), Field2::read(&storage));
+
+        assert_eq!(16, PrimitiveField::<u128, LittleEndian, 5>::SIZE);
+        assert_eq!(16, PrimitiveField::<u128, LittleEndian, 5>::SIZE);
+    }
+
+    #[test]
+    fn test_u128_bigendian() {
+        let mut storage = vec![0; 1024];
+
+        type Field1 = PrimitiveField<u128, BigEndian, 5>;
+        type Field2 = PrimitiveField<u128, BigEndian, 200>;
+
+        Field1::write(&mut storage, 10u128.pow(30));
+        Field2::write(&mut storage, 10u128.pow(28));
+
+        assert_eq!(
+            10u128.pow(30),
+            u128::from_be_bytes((&storage[5..21]).try_into().unwrap())
+        );
+        assert_eq!(
+            10u128.pow(28),
+            u128::from_be_bytes((&storage[200..216]).try_into().unwrap())
+        );
+
+        assert_eq!(10u128.pow(30), Field1::read(&storage));
+        assert_eq!(10u128.pow(28), Field2::read(&storage));
+
+        assert_eq!(16, PrimitiveField::<u128, BigEndian, 5>::SIZE);
+        assert_eq!(16, PrimitiveField::<u128, BigEndian, 5>::SIZE);
+    }
+
     #[test]
     fn test_slice() {
         let mut storage = vec![0; 1024];
